@@ -3,15 +3,14 @@ Global application functionality
 """
 
 from chk.infrastructure.exception import messages as exception_messages
-from dotmap import DotMap
 
 
 class App:
     """Global app"""
 
-    messages = DotMap({
+    messages = {
         'exception': exception_messages
-    })
+    }
 
 
 # global application object
