@@ -18,6 +18,7 @@ class HttpMethod(Enum):
 class RequestConfigNode:
     """represent request config section"""
     ROOT = 'request'
+    RETURN = 'return'
 
     # common request
     URL = 'url'
@@ -39,3 +40,4 @@ class RequestConfigNode:
     BODY_FRM_DAT = 'body[form-data]'
     BODY_JSN = 'body[json]'
     BODY_XML = 'body[xml]'
+    BODY_TXT = 'body[text]'
