@@ -5,9 +5,10 @@ from chk.modules.http.request_helper import RequestProcessorMixin_PyRequests
 from chk.modules.http.support import RequestMixin
 from chk.modules.variables.support import VariableMixin
 from chk.modules.version.support import VersionMixin
+from chk.modules.variables.constants import LexicalAnalysisType
 
 
-class HttpSpec_V072(
+class HttpSpec(
     RequestProcessorMixin_PyRequests,
     VersionMixin,
     RequestMixin,
@@ -17,12 +18,13 @@ class HttpSpec_V072(
 ):
 
     def __init__(self, file_ctx: FileContext):
-        self.file_ctx, self.document, self.validator, self.response = file_ctx, file_ctx.document, Validator(), None
+        self.file_ctx, self.document, self.validator = file_ctx, file_ctx.document, Validator()
 
-    def __work__(self) -> None:
-        VersionMixin.version_validated(self)
-        RequestMixin.request_validated(self)
-        VariableMixin.variable_validated(self)
+    def __work__(self) -> dict:
+        self.version_validated()
+        self.request_validated()
+        self.variable_validated()
 
-        ctx_document = VariableMixin.variable_process(self)
-        self.response = handle_request(self, ctx_document)
+        ctx_document = self.variable_process(LexicalAnalysisType.REQUEST)
+        out_response = handle_request(self, ctx_document)
+        return self.assemble_values(ctx_document, out_response)
